Zaber Python Serial Library
===========================

A software library to help control Zaber_ devices over a serial port.

.. _Zaber: http://www.zaber.com

Installation
------------

The Zaber Python Serial Library can be installed from PyPI using pip::
    
    pip install zaber.serial

It can also be installed directly using the ``setup.py`` file provided
with the source code::

    python setup.py install

License
-------

This library is licensed for use under the `Apache Software License 
v2.0.`_ A copy of this license is provided with the source in the file
``LICENSE.txt``.

.. _Apache Software License v2.0: http://apache.org/licenses/LICENSE-2.0

